module Graficos where

import Graphics.Gloss

-- =========================================================================
-- Esse arquivo possui todas as definicoes graficas do tetris, i.e., as funcoes
-- usadas para desenhar cada elemento na tela
-- =========================================================================

-- =========================================================================
-- Devolve um retangulo com os parametros especificados. A borda eh desenhada
-- para fora da figura, ou seja, uma figura com borda ocupa um espaco maior
-- do que a mesma figura sem borda
montaRetangulo :: Float -> Float -> Float -> Float -> Float -> Color -> Color -> Picture
montaRetangulo x y largura altura grossuraBorda corBorda corInterna = do
    let (xBorda, yBorda) = (x-grossuraBorda, y+grossuraBorda) -- Coordenadas iniciais da borda
    let offsetLargBorda  = largura + (2*grossuraBorda)        -- Esses parametros servem para que a borda contorne
    let offsetaltuBorda  = altura + (2*grossuraBorda)         -- o retangulo corretamente
    
    -- desenhando a borda e o quadrado
    let borda = Polygon [(xBorda, yBorda)
                        ,(xBorda+offsetLargBorda, yBorda)
                        ,(xBorda+offsetLargBorda, yBorda-offsetaltuBorda)
                        ,(xBorda, yBorda-offsetaltuBorda)
                        ]
    let quadradoBase = Polygon [(x, y)
                        ,(x+largura, y)
                        ,(x+largura, y-altura)
                        ,(x, y-altura)
                        ]

    -- pintando a borda e o quadrado
    let bordaPintada    = Color corBorda borda
    let quadradoPintado = Color corInterna quadradoBase

    -- figura completa
    Pictures [bordaPintada, quadradoPintado]

-- =========================================================================
-- Devolve um quadrado com os parametros especificados
montaQuadrado :: Float -> Float -> Float -> Float -> Color -> Color -> Picture
montaQuadrado x y tamanhoLado grossuraBorda corBorda corInterna = 
    montaRetangulo x y tamanhoLado tamanhoLado grossuraBorda corBorda corInterna